@@ -1,28 +1,24 @@
+# Copyright 2022 Q-CTRL. All rights reserved.
+#
+# Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
+# copying or use of this file, via any medium, is strictly prohibited.
+# Proprietary and confidential. You may not use this file except in compliance
+# with the License. You may obtain a copy of the License at
+#
+#    https://q-ctrl.com/terms
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS. See the
+# License for the specific language.
 """Module for `AsyncResult`."""
 import logging
-from importlib.util import find_spec
-from sys import modules
 from typing import (
     List,
     Optional,
 )
-from warnings import warn
 
 from graphql import GraphQLType
-
-# pylint: disable=wrong-import-position
-# Do not use `tqdm.auto` if the user is running Jupyter (IPython is loaded)
-# but ipywidgets is not available (its spec is None or its `has_location` is False).
-# For more info, see: https://github.com/tqdm/tqdm/pull/1218
-ipywidgets_spec = find_spec("ipywidgets")
-if ("IPython" in modules) and (
-    (ipywidgets_spec is None) or (not ipywidgets_spec.has_location)
-):
-    warn("For a better progress bar experience on Jupyter, install `ipywidgets`.")
-    from tqdm.std import tqdm
-else:
-    from tqdm.auto import tqdm
-# pylint: enable=wrong-import-position
+from tqdm.auto import tqdm
 
 from .result_mixin import ResultMixin
 from .utils import _get_function_name
