@@ -269,11 +269,12 @@ def gql_query(api_root, input, output):  # pylint:disable=redefined-builtin
     show_default=f"{DEFAULT_OIDC_URL}",
 )
 @click.option("--output", "--o", help="output file", default=None, show_default=None)
-def access_token(oidc_url, output):
+@click.pass_context
+def access_token(ctx, oidc_url, output):
     """
     Get JWT access token.
     """
-    oidc_session = auth(oidc_url)
+    oidc_session = ctx.invoke(auth, oidc_url=oidc_url)
     _process_output({"access_token": oidc_session.access_token}, output)
 
 
